@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301 USA.
  *
  * --
  * Roughly o2fsck performs the following operations.  Each pass' file has
@@ -226,7 +226,7 @@ errcode_t o2fsck_state_reinit(ocfs2_filesys *fs, o2fsck_state *ost)
 
 	ret = o2fsck_state_init(fs, ost);
 	if (ret) {
-		com_err(whoami, ret, "while intializing o2fsck_state.");
+		com_err(whoami, ret, "while initializing o2fsck_state.");
 		return ret;
 	}
 
@@ -876,7 +876,6 @@ int main(int argc, char **argv)
 			case 'V':
 				print_version();
 				exit(FSCK_USAGE);
-				break;
 
 			case 'r':
 				sb_num = read_number(optarg);
@@ -892,7 +891,6 @@ int main(int argc, char **argv)
 				fsck_mask |= FSCK_USAGE;
 				print_usage();
 				goto out;
-				break;
 		}
 	}
 
