@@ -17,15 +17,15 @@
  * 
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301 USA.
  *
  */
 
 #define _LARGEFILE64_SOURCE
 #define _GNU_SOURCE /* Because libc really doesn't want us using O_DIRECT? */
 
-#include <sys/types.h>
+#include <sys/sysmacros.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
@@ -569,7 +569,7 @@ int main(int argc, char **argv)
 
 	ret = build_partition_list(&dev_list, device);
 	if (ret) {
-		com_err(progname, ret, "while building partiton list");
+		com_err(progname, ret, "while building partition list");
 		goto bail;
 	}
 
